summaryrefslogtreecommitdiff
path: root/ace/Containers.h
diff options
context:
space:
mode:
authorcdgill <cdgill@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-02-06 14:28:19 +0000
committercdgill <cdgill@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-02-06 14:28:19 +0000
commit4f8e50ed18adce2d4f4edcc55e5d4d5d409d37f3 (patch)
treed6d4954d59d730fc3c0deae6b92a7463f246f059 /ace/Containers.h
parente6363b267851004b7d3b16e48816d877d18eb06f (diff)
downloadATCD-4f8e50ed18adce2d4f4edcc55e5d4d5d409d37f3.tar.gz
added first () method to Iterators
Diffstat (limited to 'ace/Containers.h')
-rw-r--r--ace/Containers.h30
1 files changed, 27 insertions, 3 deletions
diff --git a/ace/Containers.h b/ace/Containers.h
index d4ca6a45f5c..0a3675a0f8a 100644
--- a/ace/Containers.h
+++ b/ace/Containers.h
@@ -342,6 +342,10 @@ public:
// Move forward by one element in the Stack. Returns 0 when all the
// items in the Stack have been seen, else 1.
+ int first (void);
+ // Move to the first element in the Stack. Returns 0 if the
+ // Stack is empty, else 1.
+
int done (void) const;
// Returns 1 when all items have been seen, else 0.
@@ -381,6 +385,10 @@ public:
// Move forward by one element in the set. Returns 0 when all the
// items in the queue have been seen, else 1.
+ int first (void);
+ // Move to the first element in the queue. Returns 0 if the
+ // queue is empty, else 1.
+
int done (void) const;
// Returns 1 when all items have been seen, else 0.
@@ -517,8 +525,12 @@ public:
// 0 if there is no more element available.
int advance (void);
- // Move forward by one element in the Stack. Returns 0 when all the
- // items in the Stack have been seen, else 1.
+ // Move forward by one element in the list. Returns 0 when all the
+ // items in the list have been seen, else 1.
+
+ int first (void);
+ // Move to the first element in the list. Returns 0 if the
+ // list is empty, else 1.
int done (void) const;
// Returns 1 when all items have been seen, else 0.
@@ -681,6 +693,10 @@ public:
// Move forward by one element in the set. Returns 0 when all the
// items in the set have been seen, else 1.
+ int first (void);
+ // Move to the first element in the set. Returns 0 if the
+ // set is empty, else 1.
+
int done (void) const;
// Returns 1 when all items have been seen, else 0.
@@ -832,6 +848,10 @@ public:
// Move forward by one element in the set. Returns 0 when all the
// items in the set have been seen, else 1.
+ int first (void);
+ // Move to the first element in the set. Returns 0 if the
+ // set is empty, else 1.
+
int done (void) const;
// Returns 1 when all items have been seen, else 0.
@@ -954,6 +974,10 @@ public:
// Move forward by one element in the set. Returns 0 when all the
// items in the set have been seen, else 1.
+ int first (void);
+ // Move to the first element in the set. Returns 0 if the
+ // set is empty, else 1.
+
int done (void) const;
// Returns 1 when all items have been seen, else 0.
@@ -1064,7 +1088,7 @@ template <class T>
class ACE_Ordered_MultiSet_Iterator
{
// = TITLE
- // Implement an iterator over an ordered multiset.
+ // Implement a bidirectional iterator over an ordered multiset.
// This class template requires that < operator semantics be defined
// for the parameterized type <T>, but does not impose any restriction
// on how that ordering operator is implemented.